@@ -220,13 +220,39 @@ def list_countries():
 
 
 def list_layers_countries_subset(product_name, year, day, countries):
+    """
+    Filter MODIS tiles based on the product, the year, the day and the country. Country codes can be in GAUL,
+    ISO2, ISO3 or a combination of the previous.
+    @param product_name: e.g. 'mod13q1'
+    @type product_name: str
+    @param year: e.g. '2010'
+    @type year: str
+    @param day: Day of the year, e.g. '047'
+    @type day: str
+    @param countries: Comma separated string containing country codes in GAUL, ISO2 or ISO3. e.g. '8,IT,FRA'
+    @type countries: str
+    @return: Array of objects.
+    """
+    out = []
+    countries_list = countries.split(',')
+    for country_code in countries_list:
+        if country_code.isdigit():
+            out += list_layers_countries_subset_gaul(product_name, year, day, country_code)
+        elif len(country_code) == 2:
+            out += list_layers_countries_subset_iso2(product_name, year, day, country_code.upper())
+        else:
+            out += list_layers_countries_subset_iso3(product_name, year, day, country_code.upper())
+    return out
+
+
+def list_layers_countries_subset_gaul(product_name, year, day, countries):
     """
     List all the available layers for a given MODIS product, year and day.
     @param product_name: Code of MODIS product, e.g. 'MOD13Q1'
     @param year: e.g. '2010'
     @param day: Day of the year, three digits, e.g. '017'
     @param countries: GAUL codes, comma separated e.g. '18,25,34'
-    @type countries: String, comma separated
+    @type countries: str
     @return: An array of code/label/size objects.
     """
     countries_list = countries.split(',')
@@ -248,13 +274,71 @@ def list_layers_countries_subset(product_name, year, day, countries):
     return clean_out
 
 
+def list_layers_countries_subset_iso2(product_name, year, day, countries):
+    """
+    List all the available layers for a given MODIS product, year and day.
+    @param product_name: Code of MODIS product, e.g. 'MOD13Q1'
+    @param year: e.g. '2010'
+    @param day: Day of the year, three digits, e.g. '017'
+    @param countries: ISO2 codes, comma separated e.g. 'IT,FR'
+    @type countries: str
+    @return: An array of code/label/size objects.
+    """
+    countries_list = countries.split(',')
+    out = []
+    clean_out = []
+    file_names_buffer = []
+    for g2m in map:
+        if g2m['iso2_code'] in countries_list:
+            from_h = g2m['from_h']
+            to_h = g2m['to_h']
+            from_v = g2m['from_v']
+            to_v = g2m['to_v']
+            tmp = list_layers_subset(product_name, year, day, from_h, to_h, from_v, to_v)
+            out += tmp
+    for tmp in out:
+        if tmp['file_name'] not in file_names_buffer:
+            file_names_buffer.append(tmp['file_name'])
+            clean_out.append(tmp)
+    return clean_out
+
+
+def list_layers_countries_subset_iso3(product_name, year, day, countries):
+    """
+    List all the available layers for a given MODIS product, year and day.
+    @param product_name: Code of MODIS product, e.g. 'MOD13Q1'
+    @param year: e.g. '2010'
+    @param day: Day of the year, three digits, e.g. '017'
+    @param countries: ISO3 codes, comma separated e.g. 'ITA,FRA'
+    @type countries: str
+    @return: An array of code/label/size objects.
+    """
+    countries_list = countries.split(',')
+    out = []
+    clean_out = []
+    file_names_buffer = []
+    for g2m in map:
+        if g2m['iso3_code'] in countries_list:
+            from_h = g2m['from_h']
+            to_h = g2m['to_h']
+            from_v = g2m['from_v']
+            to_v = g2m['to_v']
+            tmp = list_layers_subset(product_name, year, day, from_h, to_h, from_v, to_v)
+            out += tmp
+    for tmp in out:
+        if tmp['file_name'] not in file_names_buffer:
+            file_names_buffer.append(tmp['file_name'])
+            clean_out.append(tmp)
+    return clean_out
+
+
 def day_of_the_year_to_date(day, year):
     """
     Convert a day of an year to a date
     @param day: day of the year
-    @type string i.e. "020" or "20"
+    @type day: str
     @param year: year of reference
-    @type string or int i.e. "2014" or 2014
+    @type year: str
     @return: the date of the day/year i.e. "2012-01-20"
     """
     first_of_year = datetime.datetime(int(year), 1, 1).replace(month=1, day=1)
